Anki code

# This is a test to understand how to style the cards

This is some text, my plans are:

- Get this code to look as expected
- Continue

JavaScript

    import { workspace, ConfigurationChangeEvent } from "vscode";import { getThemePaths } from "./helpers";import utils, { UpdateTrigger } from "./utils";export const activate = () => {  const paths = getThemePaths();  // regenerate on a fresh install if non-default config is set  if (utils.isFreshInstall() && !utils.isDefaultConfig()) {    utils.updateThemes(      utils.getConfiguration(),      paths,      UpdateTrigger.FRESH_INSTALL    );  }  // regenerate the theme files when the config changes  workspace.onDidChangeConfiguration((event: ConfigurationChangeEvent) => {    if (event.affectsConfiguration("catppuccin")) {      utils.updateThemes(        utils.getConfiguration(),        paths,        UpdateTrigger.CONFIG_CHANGE      );    }  });};export const deactivate = () => {};

Full of SECRETS!

## Like this one:

Something

### But not much to see 🐸

# This is an header, very important

To parse cli args you can use the built-in module`argparse`. See argparse

The steps are:

1. Initializing
2. Adding args (via `add_argument`), which can be:
   - Positional
   - Positional optional (`nargs="?"`)
   - Optional args (by adding -- before the argument's name)
   - Switch arguments (`action="store_true"`)
3. Parse
4. Accessing the value